@@ -1,7 +1,7 @@
 import json
 from typing import Any, Dict, Optional, Tuple, Union
 
-from aporia.as_code.resources.base import BaseResource, CompareStatus, NonDeletableResourceException
+from aporia.as_code.resources.base import BaseResource, CompareStatus
 from aporia.as_code.resources.data_source import DataSource
 from aporia.sdk.client import Client
 from aporia.sdk.data_sources import DataSource as _DataSource
@@ -40,31 +40,33 @@ class Dataset(BaseResource):
             group_by_column=group_by_column,
             order_by_column=order_by_column,
             group_order_sort=SortOrder(group_order_sort) if group_order_sort is not None else None,
-            raw_inputs=[
-                FieldSchema(name=name, type=FieldType(type)) for name, type in raw_inputs.items()
-            ]
-            if raw_inputs is not None
-            else [],
-            features=[
-                FieldSchema(name=name, type=FieldType(type)) for name, type in features.items()
-            ]
-            if features is not None
-            else [],
-            predictions=[
-                FieldSchema(name=name, type=FieldType(type)) for name, type in predictions.items()
-            ]
-            if predictions is not None
-            else [],
-            actuals=[
-                FieldSchema(
-                    name=name,
-                    type=FieldType(type),
-                    properties={"prediction": actual_mappings[name]},
-                )
-                for name, type in actuals.items()
-            ]
-            if actuals is not None
-            else [],
+            raw_inputs=(
+                [FieldSchema(name=name, type=FieldType(type)) for name, type in raw_inputs.items()]
+                if raw_inputs is not None
+                else []
+            ),
+            features=(
+                [FieldSchema(name=name, type=FieldType(type)) for name, type in features.items()]
+                if features is not None
+                else []
+            ),
+            predictions=(
+                [FieldSchema(name=name, type=FieldType(type)) for name, type in predictions.items()]
+                if predictions is not None
+                else []
+            ),
+            actuals=(
+                [
+                    FieldSchema(
+                        name=name,
+                        type=FieldType(type),
+                        properties={"prediction": actual_mappings[name]},
+                    )
+                    for name, type in actuals.items()
+                ]
+                if actuals is not None
+                else []
+            ),
         )
 
         if data_source_id is None and data_source_name is None and data_source is None:
@@ -140,9 +142,11 @@ class Dataset(BaseResource):
 
         checks = [
             (schema.id_column == aporia_schema["id_column"]) if compare_metadata else True,
-            (schema.timestamp_column == aporia_schema["timestamp_column"])
-            if compare_metadata
-            else True,
+            (
+                (schema.timestamp_column == aporia_schema["timestamp_column"])
+                if compare_metadata
+                else True
+            ),
             raw_inputs == schema_raw_inputs,
             features == schema_features,
             predictions == schema_predictions,
