@@ -3,7 +3,7 @@ from typing import Any, Dict, Optional, Tuple
 
 from aporia.as_code.resources.base import BaseResource, CompareStatus, NonDeletableResourceException
 from aporia.as_code.resources.dataset import Dataset
-from aporia.sdk.client import Client, BackendRuntimeError
+from aporia.sdk.client import BackendRuntimeError, Client
 from aporia.sdk.versions import Version as _Version
 
 
@@ -16,14 +16,16 @@ class Version(BaseResource):
         name: Optional[str] = None,
         serving: Optional[Dataset] = None,
         training: Optional[Dataset] = None,
+        active: bool = True,
     ):
         self.name = resource_name
+        self.active = active
         self.dependants = []
         self.sub_resources = []
         if name is None:
             name = resource_name
 
-        self._args = {"name": name}
+        self._args = {"name": name, "is_active": active}
 
         def apply_args(data, dataset):
             dataset.setarg("version_id", data["id"])
