@@ -518,7 +518,6 @@ class Stack:
                             code += f"\talertGroupTimeQuantity={action.alertGroupTimeQuantity},\n"
                         if action.alertGroupTimeUnit is not None:
                             code += f"\talertGroupTimeUnit={action.alertGroupTimeUnit},\n"
-                        
 
             # Precondition Configuration
             added_min = False
@@ -783,7 +782,7 @@ def add_model(stack: aporia.Stack):
         for unique_id, resource in self._output.items():
             resource_type = resource["_resource_type"]
             resource_name = f"{resource_type}/{unique_id.split('/')[-1]}"
-            print('Refreshing resource: {:80.80s}'.format(resource_name), end='\r')
+            print("Refreshing resource: {:80.80s}".format(resource_name), end="\r")
             try:
                 new_config[unique_id] = RESOURCE_TYPE_TO_RESOURCE_CLASS[resource_type].read(
                     client=self._client, id=resource["id"]
@@ -794,7 +793,7 @@ def add_model(stack: aporia.Stack):
             except Exception as e:
                 print(f"issue refreshing data for: {resource_type} - {unique_id}")
                 raise e
-        print("Refresh complete" + (100 * ' '))
+        print("Refresh complete" + (100 * " "))
         self._output = new_config
 
     def apply(
@@ -818,7 +817,7 @@ def add_model(stack: aporia.Stack):
                         stack_version = stack_data["version"]
                         self._output = stack_data["resources"]
                     else:
-                        stack_version = '0'
+                        stack_version = "0"
                         self._output = stack_data
                     if sdk_version < stack_version:
                         raise Exception(
