@@ -6,7 +6,7 @@ from pydantic import BaseModel, root_validator, validator
 from aporia.sdk.base import BaseAporiaResource
 from aporia.sdk.client import Client
 from aporia.sdk.messaging import MessagingIntegrationType
-from aporia.sdk.metrics import MetricType
+from aporia.sdk.metrics import AverageMethod, MetricType
 
 SEGMENT_ID_ALL_DATA = "ALLDATA"
 
@@ -176,12 +176,6 @@ class BaselineConfiguration(BaseModel):
         return result
 
 
-class AverageMethod(str, Enum):
-    MICRO = "micro"
-    MACRO = "macro"
-    WEIGHTED = "weighted"
-
-
 class MetricConfiguration(BaseModel):
     type: MetricType
     # Necessary for custom metrics
@@ -809,6 +803,7 @@ def _MonitorParamBuilder(
 
     return _MonitorParams
 
+
 def build_drift_metric(**kw) -> MetricConfiguration:
     type = MetricType.HISTOGRAM
     if kw["metric"] is not None:
@@ -817,6 +812,7 @@ def build_drift_metric(**kw) -> MetricConfiguration:
         type = MetricType.EUCLIDEAN_DISTANCE
     return MetricConfiguration(type=type)
 
+
 _MONITOR_PARAMETERS = {
     MonitorType.MODEL_ACTIVITY: {
         DetectionMethod.ANOMALY: _MonitorParamBuilder(
