@@ -16,6 +16,7 @@ class Version(BaseAporiaResource):
         self.id = data["id"]
         self.name = data["name"]
         self.model_id = data["model_id"]
+        self.is_active = data["is_active"]
 
     @classmethod
     def get_all(cls, client: Client, model_id: Optional[str] = None) -> List["Version"]:
@@ -28,7 +29,7 @@ class Version(BaseAporiaResource):
         return [cls(client=client, data=entry) for entry in response.json()]
 
     @classmethod
-    def create(cls, client: Client, name: str, model_id: str) -> "Version":
+    def create(cls, client: Client, name: str, model_id: str, is_active: bool = True) -> "Version":
         existing_versions = cls.get_all(client=client, model_id=model_id)
 
         for version in existing_versions:
@@ -44,6 +45,12 @@ class Version(BaseAporiaResource):
 
         client.assert_response(response)
 
+        if not is_active:
+            response = client.send_request(
+                f"/model-versions/{response.json()['id']}", "PUT", {"is_active": is_active}
+            )
+            client.assert_response(response)
+
         return cls(client=client, data=response.json())
 
     def create_dataset(
@@ -75,8 +82,7 @@ class Version(BaseAporiaResource):
         response = self.client.send_request(
             f"/model-versions/{self.id}",
             "PUT",
-            {"name": kwargs["name"]},
-            url_search_replace=("/api/v1/", "/v1/crud-service/"),
+            kwargs,
         )
         self.client.assert_response(response)
         self.__update_members(response.json())
