@@ -2,6 +2,8 @@ from aporia.sdk.widgets.base import BaseWidget
 from aporia.sdk.widgets.data_health_table_widget import DataHealthTableWidget
 from aporia.sdk.widgets.distribution_widget import DistributionWidget
 from aporia.sdk.widgets.histogram_over_time_widget import HistogramOverTimeWidget
+from aporia.sdk.widgets.metric_by_segment_widget import MetricBySegmentWidget
+from aporia.sdk.widgets.metric_correlation_widget import MetricCorrelationWidget
 from aporia.sdk.widgets.metric_widget import MetricWidget
 from aporia.sdk.widgets.text_widget import TextWidget
 from aporia.sdk.widgets.timeseries_widget import TimeSeriesWidget
